@@ -36,7 +36,7 @@ BEGIN
   our %EXPORT_TAGS = ( go => [@EXPORT_OK] );
 }
 
-our $VERSION = '0.29';
+our $VERSION = '0.30';
 
 require App::MechaCPAN::Perl;
 require App::MechaCPAN::Install;
@@ -58,6 +58,7 @@ our @args = (
   'quiet|q!',
   'no-log!',
   'directory|d=s',
+  'build-reusable-perl!',
 );
 
 # Timeout when there's no output in seconds
@@ -136,7 +137,20 @@ sub main
   local $VERBOSE = $options->{verbose} // $VERBOSE;
   local $QUIET   = $options->{quiet}   // $QUIET;
 
-  my $cmd    = ucfirst lc shift @argv;
+  my $cmd;
+
+  if ( $options->{'build-reusable-perl'} )
+  {
+    $cmd = 'Perl';
+    $options->{'build-reusable'} = delete $options->{'build-reusable-perl'};
+    if ( lc $argv[0] eq 'perl' )
+    {
+      info("Option build-reusable-perl implies the perl command, it can be omitted");
+      shift @argv;
+    }
+  }
+
+  my $cmd    = $cmd // ucfirst lc shift @argv;
   my $pkg    = join( '::', __PACKAGE__, $cmd );
   my $action = eval { $pkg->can('go') };
   my $munge  = eval { $pkg->can('munge_args') };
@@ -747,7 +761,8 @@ sub fetch_file
     {
       unlink $tmpfile;
     }
-    die $ff->error || "Could not download $url";
+    my $error = $ff->error || "Could not download $url";
+    die "$error\n";
   }
 
   if ( $where ne $result )
@@ -1291,7 +1306,7 @@ MechaCPAN was created because installation of a self-contained deployment requir
 
 In development these tools are invaluable, but when deploying a package, installing at least 4 packages from github, CPAN and the web just for a small portion of each tool is more than needed. App::MechaCPAN aims to be a single tool that can be used for deploying packages in a automated fashion.
 
-App::MechaCPAN focuses on the aspects of these tools needed for deploying packages to a system. For instance, it will read and use carton's C<cpanfile.snapshot> files, but cannot create them. To create C<cpanfile.snapshot files>, you must use carton.
+App::MechaCPAN focuses on the aspects of these tools needed for deploying packages to a system. For instance, it will read and use carton's C<cpanfile.snapshot> files, but cannot create them. To create C<cpanfile.snapshot> files, you must use carton.
 
 =head2 Should I use App::MechaCPAN instead of <tool>
 
@@ -1365,6 +1380,34 @@ A log is normally outputted into the C<local/logs> directory. This option will p
 
 Changes to a specified directory before any processing is done. This allows you to specify what directory you want C<local/> to be in. If this isn't provided, the current working directory is used instead.
 
+=head2 --build-reusable-perl
+
+Giving this options will override the mode of operation and generate a reusable, relocatable L<perl> archive. This accepts the same parameters as the L<Perl|App::MechaCPAN::Perl> command (i.e. L</devel> and L</threads>) to generate the binary. Note that the C<lib/> directory is always included unless the L<--skip-lib|App::MechaCPAN::Perl/skip-lib> option is included. The archive name will generally reflect what systems the resuling archive can run on. Because of the nature of how L<perl> builds binaries, it cannot guarantee that it will work on any given system. This option will have the best luck if you use it with the same version of a distribution.
+
+Once you have a reusable binary archive, L<App::MechaCPAN::Perl> can use that archive as a source file and install the binaries into the local directory. This can be handy if you are building a lot of identical systems and only want to build L<perl> once.
+
+The exact parameters included in the archive name are:
+
+=over
+
+=item * The version built
+
+=item * The architecture name, as found in the first piece of $Config{archname}
+
+=item * The Operating System, as found in $Config{osname}
+
+=item * Optionally notes if it was built with threads
+
+=item * The name of the libc used
+
+=item * The version of the libc used
+
+=item * The C<so> version of libraries used, with common libaries being abbreviated
+
+=back
+
+An example archive name would be C<perl-v5.36.0-x86_64-linux-glibc-2.35-y1.1n2.0u1.tar.xz>
+
 =head2 C<$ENV{MECHACPAN_TIMEOUT}>
 
 Every command that C<App::MechaCPAN> runs is given an idle timeout before it is killed and a failure is returned. This timeout is reset every time the command outputs to C<STDOUT> or C<STDERR>. Using the environment variable C<MECHACPAN_TIMEOUT>, you can override or disable this timeout. It is always in seconds and setting it to 0 will disable it. The default is 60 seconds.
